# Sample gnucash books

This folder holds a set of gnucash books used for testing, examples and debugging.



## Default empty books

The following gnucash books can be used to introspect the SQL schema:
- reference/default_2_6_21_basic.gnucash: empty gnucash books created with gnucash 2.6.21 and no specific options
- reference/default_2_6_21_full_options.gnucash: empty gnucash books created with gnucash 2.6.21 with multiple options enabled (trading accounts, ...)
- reference/default_piecash_0_18_basic.gnucash: empty gnucash books created by piecash
